from .decorators import DocInherit as method_doc_inherit  # noqa

__title__ = "python-doc-inherit"
__summary__ = "Utilities to inherit method documentation from parent classes."
__uri__ = "https://github.com/kavdev/python-doc-inherit/"

__version__ = "0.2.0"

__author__ = "Alexander Kavanaugh"
__email__ = "alex@kavdev.io"

__license__ = "MIT"
__license__ = "License :: OSI Approved :: MIT License"
__copyright__ = "Copyright (c) 2016 Alexander Kavanaugh"
